#include "xparameters.h"
#include "xuartns550.h"
  
#define UART_BASEADDR XPAR_RS232_UART_0_BASEADDR
#define UART_CLOCK    XPAR_XUARTNS550_CLOCK_HZ
#define UART_BAUDRATE 57600 /* real hardware */
 
#define ESCAPE                  0x1b
#define FRAME_SYNC              0x7E
#define ACK                     0xA5
#define NACK                    0x5A


//Protocol attributes.
unsigned char *ReceiveBuffer;
unsigned int ReceiveSize;
unsigned int ReceiveCount;
volatile unsigned int * leds = (volatile unsigned int *)0x40040000;
volatile unsigned int * leds_conf = (volatile unsigned int *)0x40040004;

XUartNs550 uart;

typedef void ( funcao )( void );

int main( void ) {

  *leds_conf = 0x00000000;
  *leds = 1;
  funcao *func; 
  volatile unsigned char *receiveBuffer = 0;
  func = ( funcao * ) receiveBuffer;

  XUartNs550_Initialize(&uart, XPAR_RS232_UART_0_DEVICE_ID);
  XUartNs550_SetBaudRate(&uart, UART_BAUDRATE);

  XUartNs550_SetBaud(UART_BASEADDR, UART_CLOCK, UART_BAUDRATE);
  XUartNs550_mSetLineControlReg(UART_BASEADDR, XUN_LCR_8_DATA_BITS);

  print("\r\n");
  print("ML403 EPOS Bootloader\r\n");
  print("By Trier & HugoM - 27/07/2006...\r\n");

  //Wait until we can write on DDR
  unsigned int timeout = 0;
  do {
    *receiveBuffer = 0xAA;
    if(timeout++ > 5) {
       print("Timeout! Couldn't write on DDR Memory. Reset CPU\r\n");
	   exit(0);
	}
  } while (*receiveBuffer != 0xAA);

  print("\r\n");
  print("You can now transmit image ...\r\n");

  unsigned char byte = 0;
  unsigned char check_sum;
  unsigned char ack = ACK;
  unsigned char nack = NACK;

  do{
    XUartNs550_Recv(&uart, (Xuint8*)(&byte), 1);
  } while(byte != FRAME_SYNC);

  do{
    XUartNs550_Recv(&uart, (Xuint8*)(&byte), 1);
  } while (byte == FRAME_SYNC);

  ReceiveSize = 0;
  check_sum = 0;
  unsigned int aux;

  *leds = 2;

  //Receive Size of Buffer
  int i;
  for(i=0; i < 4; i++) {
    byte = XUartNs550_RecvByte(UART_BASEADDR);
    aux = 0;
    aux = byte;
    aux <<= ( 8 * i );
    ReceiveSize |= aux;
    check_sum ^= byte;
  };

  //Verifica CheckSum
  byte = XUartNs550_RecvByte(UART_BASEADDR);
  if( byte != check_sum ) {
    XUartNs550_Send(&uart, (Xuint8*)(&nack), 1);
    while(XUartNs550_IsSending(&uart));
    return(0);
  }
  XUartNs550_Send(&uart, (Xuint8*)(&ack), 1);
  while(XUartNs550_IsSending(&uart));

  *leds = 3;

  //Recebe Dados
  check_sum = 0;
  for( ReceiveCount=0; ReceiveCount < ReceiveSize; ReceiveCount++ ) {
    byte = XUartNs550_RecvByte(UART_BASEADDR);
    ReceiveBuffer[ ReceiveCount ] = byte;
    check_sum ^= byte;
  }

  *leds = 4;


  byte = XUartNs550_RecvByte(UART_BASEADDR);
  if( byte != check_sum ) {
    XUartNs550_Send(&uart, (Xuint8*)(&nack), 1);
    while(XUartNs550_IsSending(&uart));
    return( 0 );
  }
  XUartNs550_Send(&uart, (Xuint8*)(&ack), 1);
  while(XUartNs550_IsSending(&uart));

  *leds = 5;

  print("Done! Branching for Image code\r\n");

  func();

};
